#
# spec file for package synaptiks
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright 2009 Buschmann <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           synaptiks
Version:        0.8.1
Release:        17.2
Summary:        A touchpad configuration and management tool for KDE
License:        BSD-2-Clause
Group:          Hardware/Other
Url:            http://synaptiks.readthedocs.org/
Source0:        http://pypi.python.org/packages/source/s/synaptiks/%{name}-%{version}.tar.bz2
# Patch sent upstream: https://github.com/lunaryorn/synaptiks/pull/67
Patch0:         czech.patch
# PATCH-FIX-OPENSUSE fix_help.diff Link (Christian Trippe, Link to the online help, bnc#800708)
Patch1:         fix_help.diff
# PATCH-FIX-UPSTREAM remove-several-features-that-will-no-longer-be-exposed.patch -- removes the features that got removed in synaptics >= 1.7
Patch2:         remove-several-features-that-will-no-longer-be-exposed.patch
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  python-devel
BuildRequires:  python-distribute
BuildRequires:  python-kde4
BuildRequires:  python-pyudev
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
Requires:       kdebase4-workspace
Requires:       python-distribute
Requires:       python-kde4
Requires:       python-pyudev
%if 0%{?suse_version} > 1210
Requires:       xf86-input-synaptics
%else
Requires:       xorg-x11-driver-input
%endif
Recommends:     dbus-1-python
Recommends:     upower
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%kde4_runtime_requires
%py_requires

%description
synaptiks is a touchpad configuration and management tool for KDE. It provides
a System Settings module to configure both basic and more advanced settings of
the touchpad. Additionally it comes with a little system tray application,
which “manages” the touchpad. It does not only provide a global hotkey to
conveniently switch the touchpad on or off, it can also do this automatically
while you are typing, or if you plug in an external mouse.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot} --record-rpm=INSTALLED_FILES --single-version-externally-managed

%if 0%{?suse_version}
%suse_update_desktop_file -r synaptiks Qt KDE Settings HardwareSettings
%suse_update_desktop_file %{buildroot}%{_sysconfdir}/xdg/autostart/synaptiks_init_config.desktop
%endif

%kde_post_install
%fdupes -s %{buildroot}
%find_lang %{name}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc CHANGES.rst COPYING README.rst
%{_sysconfdir}/xdg/autostart/synaptiks_init_config.desktop
%{_datadir}/autostart/synaptiks_autostart.desktop
%{_kde4_applicationsdir}/synaptiks.desktop
%{_kde4_appsdir}/synaptiks/
%{_kde4_bindir}/synaptiks
%{_kde4_bindir}/synaptikscfg
%{_kde4_iconsdir}/hicolor/scalable/apps/synaptiks.svgz
%{_kde4_servicesdir}/kcm_synaptiks.desktop
%{python_sitelib}/synaptiks-*
%{python_sitelib}/synaptiks/

%changelog
* Sun Sep 22 2013 hrvoje.senjan@gmail.com
- Unconditionally apply previously added patch
* Tue Apr  2 2013 hrvoje.senjan@gmail.com
- Added remove-several-features-that-will-no-longer-be-exposed.patch,
  removes features that got removed in synaptics driver >= 1.7
* Tue Mar  5 2013 stefan.bruens@rwth-aachen.de
- replace Requires: xorg-x11-driver-input metapackage
  with xf86-input-synaptics
* Wed Jan 30 2013 ctrippe@opensuse.org
- add patch fix_help.diff to change to path for the correct manual
  (bnc#800708)
* Sat Jan 19 2013 tchvatal@suse.com
- Update czech trans, as it contained complete garbage.
  * Adds czech.patch
* Sat Mar 10 2012 asterios.dramis@gmail.com
- Spec file updates:
  * Replaced python-setuptools with python-distribute and pyudev with
    python-pyudev in BuildRequires: and Requires: (current package names).
  * Removed libkde4-devel from BuildRequires: (not needed).
  * Added dbus-1-python and upower in recommended packages based on package
    requirements.
* Sat Feb 18 2012 asterios.dramis@gmail.com
- Update to 0.8.1
  * Website now hosted on http://synaptiks.readthedocs.org
  * Mailing list now hosted at synaptiks@librelist.com
  * Added Czech translation
  * Fixed syntax error in ``synaptiks_init_config.desktop``
* Sat Oct  8 2011 ctrippe@opensuse.org
- Update to 0.8.0
  * Removed build-time dependency against kdesdk-scripts
  * Fixed “Defaults” button in configuration dialog of tray application
  * Fixed KeyError on unknown event types in keyboard monitor
  * Fixed crash after resume from suspend
  * Fixed support for non-usb devices
  * Added Danish translation (thanks to Martin Schlander)
* Tue Sep 13 2011 toddrme2178@gmail.com
- Added py_requires macro (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Mon Sep 12 2011 ctrippe@opensuse.org
- Require python-distribute which is needed for the systray-applet
  (bnc#717168)
* Mon Sep  5 2011 asterios.dramis@gmail.com
- Update to 0.7.0
  * Require pyudev 0.8 or newer now
  * Increased maximum for minimum and maximum speed to 10.0
  From 0.6.2
  * Fixed punctuation
- Spec file updates
  * Updates in BuildRequires: entries.
  * Changed License: to BSD-2-Clause.
  * Updated Url: entry.
  * Changed Group: to Hardware/Other.
  * Updates in Requires: entries.
  * Updates in Summary: and %%description entries.
  * Build package as noarch.
  * Changed synaptiks.desktop file Categories entry to
    Settings;HardwareSettings.
  * Fixed some rpmlint warnings.
  * Minor other updates.
- Removed dont-warn-no-touchpad.diff, systemsettings_category_bnc637585.diff
  and two_finger_emulation_bnc658800.diff patches (they don't apply to the
  current version which is python based instead of c++).
* Wed May 25 2011 cgiboudeaux@gmx.com
- Update to 0.6.1
  * Fixed installation of autostart files
  * Use XRecord for keyboard management, if available
  * Reinitialize mouse monitoring and mouse display if the system is resuming from suspend
  * Fixed touchpad search on 64-bit systems
  * Fixed segfault on failed connection to X11 display in synaptikscfg
  * Show a clean error message instead of a traceback, when no touchpad is found by synaptiks cfg
  * Fixed corner coasting configuration to actually reflect the corner coasting setting from the touchpad driver
  * Fixed property data extraction on 64 bit architectures
  * Fixed source distribution to include the handbook
* Mon Jan 10 2011 ctrippe@gmx.net
- add support for two-finger emulation (bnc#658800)
* Sun Jan  2 2011 ctrippe@gmx.net
- Put the KCM-Module under Input devices in System Settings (bnc#637585)
* Tue May 25 2010 llunak@novell.com
- do not warn about missing touchpad
* Sun Apr 11 2010 tittiatcoke@gmail.com
- update to 0.4
  Features added
  * Added fast taps setting
  * Added two-finger scrolling settings
  * Added circular scrolling angle setting
  * Added circular touchpad setting
  * Added motion speed settings
  * Added setting to always enable edge motion
  * Added tap-and-drag settings
  * Added scrolling distance settings
  * Use default settings from the touchpad driver
  Bugs fixed
  * Fixed crash caused by erroneous D-Bus replies
  Miscellaneous changes
  * Use sliders in user interface
* Mon Mar 29 2010 thomas@tleine.de
- backport rev 1097582 from kde repository to Version 0.3.2
  * fix crashing when configuration is opened in system-settings
    b.k.o #226005 or http://bitbucket.org/lunar/synaptiks/issue/32/
* Fri Feb  5 2010 tittiatcoke@gmail.com
- update to version 0.3.2
  * Fixed German translation
  * Fixed “Ignore the following mouse devices” setting
* Tue Feb  2 2010 tittiatcoke@gmail.com
- update to version 0.3.1
  * updated Danish translation
  * updated Turkish translation
* Sat Jan 30 2010 tittiatcoke@gmail.com
- update to version 0.3.0
  * “Capabilities” page renamed to “Touchpad information” page
  * Touchpad state at startup can be configured
  * Touchpad name is shown in touchpad information page
  * Split synaptiks into a KDED daemon, a System Settings module,
    and a Plasma applet
* Tue Jan  5 2010 tittiatcoke@gmail.com
- update to version 0.2.1
  * Added Danish translation
  * Fixed potential memory leak
* Wed Nov 25 2009 tittiatcoke@gmail.com
- Update to version 0.2.0
  * New:
    + The delay before re-enabling the touchpad after keyboard activity
    can be configured
    + Shortcuts can be configured from context menu
    + The treshold speed for conventional coasting can be configured
    + Added tapping settings
    + Added handbook
    + Added Russian and Turkish translation
  * Bugs:
    + Show only one notification for each error
    + Notification configuration merged into a single dialog accessible
    from context menu
    + Disable synaptiks, if no touchpad is found
    + Fixed version check to maintain compatibility with Xinput 2.0
    + The touchpad is no longer switched on by stopping typing, if it was
    disabled by a plugged mouse device
    + The touchpad is switched on again, if mouse device management is disabled
    + Handle changes to the list of ignored mouse devices correctly
